glia.widgets.editor package
===========================

Subpackages
-----------

.. toctree::

    glia.widgets.editor.lexers

Submodules
----------

glia.widgets.editor.tabs module
-------------------------------

.. automodule:: glia.widgets.editor.tabs
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: glia.widgets.editor
    :members:
    :undoc-members:
    :show-inheritance:
